#include <qlabel.h>
#include <qbitmap.h>

#include "toolbar.moc"

static int bitmapSize(unsigned char* BitTomb)
{
   return((BitTomb[2]+BitTomb[3]*256)+(BitTomb[4]+BitTomb[5]*256)*65536);
}

// ******* NewWidget ********************

NWidget::NWidget( QWidget *parent=0, const char *name=0, WFlags f=0 )
  :QWidget( parent, name, f )
{
}

void NWidget::resizeEvent( QResizeEvent *e )
{
   emit sizeChanged( e->size().width(), e->size().height());   
}

void NWidget::paintEvent( QPaintEvent *e )
{
   emit sizeChanged( width(), height());   
}

// ******* QToolButton ********************

QToolButton::QToolButton( QWidget *parent, unsigned char* BitTomb)
            :QLabel( parent )
{
   setFrameStyle( Panel | Raised );
   setLineWidth(1);
   pmap.loadFromData(BitTomb,bitmapSize(BitTomb));
   pmap.setMask( pmap.createHeuristicMask() );   
   setBackgroundColor(0xc0c0c0);
   setGeometry(0,0,pmap.width()+4,pmap.height()+4);
   rX=1;
   rY=1;
   pushed=FALSE;
}

void QToolButton::mousePressEvent( QMouseEvent *m )
{
   setFrameStyle( Panel | Sunken );
   setLineWidth(1);
   rX=2; rY=2;
   repaint();
   pushed=(m->button()==LeftButton);
}

void QToolButton::mouseReleaseEvent( QMouseEvent *m )
{
   QString s;
   setFrameStyle( Panel | Raised );
   setLineWidth(1);
   rX=1; rY=1;
   repaint();
   if(((m->pos().x()>=0 && m->pos().x()<=width()) &&
       (m->pos().y()>=0 && m->pos().y()<=height()))   && 
       (m->state()==LeftButton && pushed))
      emit clicked();
   pushed=FALSE;
}

void QToolButton::paintEvent ( QPaintEvent *p) 
{
   QLabel::paintEvent(p);
   bitBlt(this, rX, rY, &pmap);
}

// ******* QIDButt *********

QIDButton::QIDButton( QWidget *parent,int bnID, unsigned char* Bit1Tomb,
unsigned char* Bit2Tomb)
            :QLabel( parent )
{
   setFrameStyle( Panel | Raised );
   setLineWidth(1);
   pmap1.loadFromData(Bit1Tomb,bitmapSize(Bit1Tomb));
   pmap2.loadFromData(Bit2Tomb,bitmapSize(Bit2Tomb));
   setBackgroundColor(0xc0c0c0);
   setGeometry(0,0,pmap1.width()+4,pmap1.height()+4);
   anID=bnID;
   rX=1;
   rY=1;
   State=0;
}

void QIDButton::setState(int aState)
{
   State=aState;
   repaint();
};

void QIDButton::mousePressEvent( QMouseEvent *m )
{
   setFrameStyle( Panel | Sunken );
   setLineWidth(1);
   rX=2; rY=2;
   repaint();
}

void QIDButton::mouseReleaseEvent( QMouseEvent *m )
{
   QString s;
   setFrameStyle( Panel | Raised );
   setLineWidth(1);
   rX=1; rY=1;
   repaint();
   if((m->pos().x()>=0 && m->pos().x()<=width()) &&
      (m->pos().y()>=0 && m->pos().y()<=height()))
      emit clicked( anID );
}

void QIDButton::paintEvent ( QPaintEvent *p) 
{
   QLabel::paintEvent(p);
   if( State == 0 )
     bitBlt(this, rX, rY, &pmap1);
   else
     bitBlt(this, rX, rY, &pmap2);
}

// ******* QToolBar *************************

QToolBar::QToolBar( NWidget *parent, int NumGomb, TGombRekord *Gombsor )
         :QLabel( parent )
{
  int i,pos;
  
  GombNum=NumGomb;
  
  setFrameStyle( Box | Plain );
  setLineWidth(0);
  setBackgroundColor(0xa0a0a0);
  setAlignment( AlignLeft );
  
  QToolButton *btn;
  
  pos=2; baseYPoint=0;
  for(i=0;i<NumGomb;i++)
    {
      btn = new QToolButton( this, Gombsor[i].BitTomb);
      btn->move( pos, 1);
      if(Gombsor[i].slot != NULL)
        connect( btn, SIGNAL(clicked()), parent, Gombsor[i].slot );
      pos=pos+24+Gombsor[i].Szomszed;
      if(strlen(Gombsor[i].tiptext)>0)
        QToolTip::add( btn, Gombsor[i].tiptext );
    }     
  connect(parent,SIGNAL(sizeChanged(int,int)),SLOT(getNewSize(int,int)));
}

void QToolBar::setBaseYPoint( int YY )
{
   baseYPoint=YY;
}

void QToolBar::getNewSize( int ww, int hh )
{
   setGeometry(0, baseYPoint, ww, 26 );
}

void QToolBar::paintEvent( QPaintEvent *pe )
{
  QLabel::paintEvent( pe );
  setGeometry(0, baseYPoint, parentWidget()->width(), 26 );  
  QPainter p; 
  p.begin( this );
  p.setPen( 0x808080 );
  p.drawLine(0,height()-1,width()-1,height()-1);
  p.end();  
}
